"""Instagram platform integration."""

from marqetive.platforms.instagram.client import InstagramClient
from marqetive.platforms.instagram.models import InstagramPostRequest

__all__ = ["InstagramClient", "InstagramPostRequest"]
